Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
Server handles listening for connection check requests using UDP
func NewServerWithNetstack ¶
func NewServerWithNetstack(serverAddr string, serverPort uint16, newtID string, tnet *netstack2.Net) *Server
NewServerWithNetstack creates a new connection test server using WireGuard netstack
func (*Server) RestartWithNetstack ¶
RestartWithNetstack stops the current server and restarts it with netstack
Click to show internal directories.
Click to hide internal directories.